==> jc-1.4.0.tar.gz: soot/dava/internal/AST/ASTStatementSequenceNode.h <==
// public class soot.dava.internal.AST.ASTStatementSequenceNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class fd1bcf22faf18f4b soot_dava_internal_AST_ASTStatementSequenceNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTNode

#include "soot/dava/internal/AST/ASTNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTStatementSequenceNode_H_
#define _JC_soot_dava_internal_AST_ASTStatementSequenceNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_refs	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$refs	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$nonrefs	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vmethods	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtable	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtype	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_AST_ASTStatementSequenceNode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *);
extern void _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method$perform__5fAnalysis$22b39eae4f6a8345(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTStatementSequenceNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *);
extern void _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method_info$perform__5fAnalysis$22b39eae4f6a8345;
extern _jc_method _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *);
	void	(*perform__5fAnalysis$22b39eae4f6a8345)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vmethods	soot_dava_internal_AST_ASTStatementSequenceNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_refs {
	struct _jc_object	*statementSequence;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$refs {
    _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_refs	soot_dava_internal_AST_ASTStatementSequenceNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_nonrefs	soot_dava_internal_AST_ASTStatementSequenceNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object {
	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtype _jc_soot_dava_internal_AST_ASTStatementSequenceNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTStatementSequenceNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTStatementSequenceNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTStatementSequenceNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/AST/ASTStatementSequenceNode.h <==
// public class soot.dava.internal.AST.ASTStatementSequenceNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class fd1bcf22faf18f4b soot_dava_internal_AST_ASTStatementSequenceNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTNode

#include "soot/dava/internal/AST/ASTNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTStatementSequenceNode_H_
#define _JC_soot_dava_internal_AST_ASTStatementSequenceNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_refs	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$refs	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$nonrefs	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vmethods	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtable	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtype	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_AST_ASTStatementSequenceNode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method$perform__5fAnalysis$22b39eae4f6a8345(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTStatementSequenceNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method_info$perform__5fAnalysis$22b39eae4f6a8345;
extern _jc_method _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_AST_ASTStatementSequenceNode$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *) _JC_JCNI_ATTR;
	void	(*perform__5fAnalysis$22b39eae4f6a8345)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vmethods	soot_dava_internal_AST_ASTStatementSequenceNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_refs {
	struct _jc_object	*statementSequence;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$refs {
    _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_refs	soot_dava_internal_AST_ASTStatementSequenceNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTStatementSequenceNode$sub_nonrefs	soot_dava_internal_AST_ASTStatementSequenceNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTStatementSequenceNode$object {
	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTStatementSequenceNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTStatementSequenceNode$vtype _jc_soot_dava_internal_AST_ASTStatementSequenceNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTStatementSequenceNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTStatementSequenceNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTStatementSequenceNode_H_ */
